@@ -653,3 +653,29 @@ print.UdfRuntime = function(x, ...) {
     
     print.default(x)
 }
+
+#' @export
+print.ProviderList = function(x, ...) {
+  cat("OIDC Provider:\n")
+  cat(paste("-",names(x)),sep="\n")
+}
+
+#' @export
+print.Provider = function(x, ...) {
+  cat(x$id,"\n")
+  cat("Title:",x$title,"\n")
+  cat("Description:",x$description,"\n")
+  cat("Issuer:",x$issuer,"\n")
+  cat("Scope:",paste(x$scopes,collapse=" "),"\n")
+  
+  if ("default_clients" %in% names(x) && length(x$default_clients) > 0) {
+    cat("\n")
+    cat("Default client configurations provided.\n")
+    client_id = .get_default_client_ids(x)
+    if (length(client_id > 1)) {
+      message(paste0("Multiple default clients detected for this authentication provider. You might need to login with a custom configuration for `client_id` with one of the following ids: ",paste0(client_id,collapse=", ")))
+    }
+  } else {
+    message("The back-end provider did not specify default clients. Use a back-end specific configuration on login! For more information contact the openEO back-end provider.")
+  }
+}
